require("tidyverse")

this.dir <- dirname(parent.frame(2)$ofile)
setwd(this.dir)

data <- na.omit(read.csv("raw.csv", na.strings=c("","NA"))) # ignore lines describing multiple payloads
data <- data %>%
  mutate(
    Suc_bin = ifelse(Suc == "S", 1, 0)
  )

# The first word in LV.type (launch vehicle type) can be roughly interpreted as a launcher family, e.g. Ariane, Atlas, etc
data$family <- as.factor(sub(pattern = "[^a-zA-Z].*", replacement = "", x = data$LV.Type))

# Site of launch contains detailed info such as specific launch pad, extract the space port itself, (e.g. CC = Cape Canaveral, etc)
SpacePortText <- sub(pattern = "[^a-zA-Z].*", replacement = "", x = data$Site)
data$spacePort <- as.factor(SpacePortText)

# Use the space port as a proxy for the country
SpacePortText <- sub(pattern = "^(HADC|F|WI|PA|V|CC|KSC|MARS|VS|SMLC|KMR)$", replacement = "_USA", SpacePortText)
SpacePortText <- sub(pattern = "^(WEN|TYSC|XSC|JQ|DEBO)$", replacement = "_China", SpacePortText)
SpacePortText <- sub(pattern = "^(YAS|GTsP|VOST|GNIIPV|GIK|NIIP)$", replacement = "_Russia/USSR", SpacePortText)
SpacePortText <- sub(pattern = "^(CSG)$", replacement = "_Europe", SpacePortText)
SpacePortText <- sub(pattern = "^(TNSC|KASC)$", replacement = "_Japan", SpacePortText)
SpacePortText <- sub(pattern = "^(SHAR)$", replacement = "_India", SpacePortText)
SpacePortText <- sub(pattern = "^[^_].*$", replacement = "Unk", SpacePortText)
SpacePortText <- sub(pattern = "_", replacement = "", SpacePortText)
data$country <- as.factor(SpacePortText)

# For convenience
data$year <- as.numeric(sub(pattern = "[^0-9].*", replacement = "", x = data$X..Launch))
data$launchIndex <- ave( 1:nrow(data), data$LV.Type, FUN=function(x) 1:length(x) )

data <- data %>% rename(
  rocketType = LV.Type, 
  success = Suc_bin, 
  launchCode = X..Launch,
  launchDateUTC = Launch.Date..UTC.,
  firstPayload = PL.Name,
  firstPayloadOrig = Orig.PL.Name,
  launchVehicleSerialNumber = LV.S.N)

# There is a clash for USSR's N-1 and Japan's N-2 so keeping only 4 main countries for now
data <- data %>% filter(country == 'Russia/USSR' | country == 'USA' | country == 'Europe' | country == 'China')

write.csv(data, "processed.csv")

counts <- data %>%
  group_by(rocketType, country, family) %>%
  summarise(
    numberOfLaunches = n(),
    numberOfFailures = numberOfLaunches - sum(success)
  )

write.csv(counts, "counts.csv")


# Basic visualization

ggplot(counts, aes(x = numberOfFailures / numberOfLaunches)) +
  geom_histogram() + theme_bw()

ggsave("../../www/figs/hierarchical_naive_hist.jpg")
